==> aerospike-client-csharp-3.2.1.zip: aerospike-client-csharp-3.2.1/AerospikeClient/Policy/RecordExistsAction.cs <==
/* 
 * Copyright 2012-2016 Aerospike, Inc.
 *
 * Portions may be licensed to Aerospike, Inc. under one or more contributor
 * license agreements.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
namespace Aerospike.Client
{
	/// <summary>
	/// How to handle writes when the record already exists.
	/// </summary>
	public enum RecordExistsAction
	{
		/// <summary>
		/// Create or update record.
		/// Merge write command bins with existing bins.
		/// </summary>
		UPDATE,

		/// <summary>
		/// Update record only. Fail if record does not exist.
		/// Merge write command bins with existing bins.
		/// </summary>
		UPDATE_ONLY,

		/// <summary>
		/// Create or update record.
		/// Delete existing bins not referenced by write command bins.
		/// Supported by Aerospike 2 server versions >= 2.7.5 and 
		/// Aerospike 3 server versions >= 3.1.6.
		/// </summary>
		REPLACE,

		/// <summary>
		/// Update record only. Fail if record does not exist.
		/// Delete existing bins not referenced by write command bins.
		/// Supported by Aerospike 2 server versions >= 2.7.5 and 
		/// Aerospike 3 server versions >= 3.1.6.
		/// </summary>
		REPLACE_ONLY,

		/// <summary>
		/// Create only.  Fail if record exists. 
		/// </summary>
		CREATE_ONLY
	}
}

==> aerospike-client-csharp-3.3.2.zip: aerospike-client-csharp-3.3.2/AerospikeClient/Policy/RecordExistsAction.cs <==
/* 
 * Copyright 2012-2016 Aerospike, Inc.
 *
 * Portions may be licensed to Aerospike, Inc. under one or more contributor
 * license agreements.
 *
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not
 * use this file except in compliance with the License. You may obtain a copy of
 * the License at http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
namespace Aerospike.Client
{
	/// <summary>
	/// How to handle writes when the record already exists.
	/// </summary>
	public enum RecordExistsAction
	{
		/// <summary>
		/// Create or update record.
		/// Merge write command bins with existing bins.
		/// </summary>
		UPDATE,

		/// <summary>
		/// Update record only. Fail if record does not exist.
		/// Merge write command bins with existing bins.
		/// </summary>
		UPDATE_ONLY,

		/// <summary>
		/// Create or update record.
		/// Delete existing bins not referenced by write command bins.
		/// Supported by Aerospike server versions >= 3.1.6.
		/// </summary>
		REPLACE,

		/// <summary>
		/// Update record only. Fail if record does not exist.
		/// Delete existing bins not referenced by write command bins.
		/// Supported by Aerospike server versions >= 3.1.6.
		/// </summary>
		REPLACE_ONLY,

		/// <summary>
		/// Create only.  Fail if record exists. 
		/// </summary>
		CREATE_ONLY
	}
}
